#!/usr/bin/env python
#coding:utf-8

import time
import smbus
#import logx
import logging
BUS = smbus.SMBus(1)
BLEN = 1

class LCD1602:
	def __init__(self, address):
		global LCD_ADDR
		LCD_ADDR = address
		self.init_lcd()

	def turn_light(self, key):
		BLEN = key
		if key ==1:
			BUS.write_byte(LCD_ADDR ,0x08)
			logging.info('LCD executed turn on BLight')
		else:
			BUS.write_byte(LCD_ADDR ,0x00)
			logging.info('LCD executed turn off BLight')

	def write_word(self, addr, data):
		temp = data
		if BLEN == 1:
			temp |= 0x08
		else:
			temp &= 0xF7
		BUS.write_byte(addr ,temp)

	def send_command(self, comm):
		# Send bit7-4 firstly
		buf = comm & 0xF0
		buf |= 0x04               # RS = 0, RW = 0, EN = 1
		self.write_word(LCD_ADDR ,buf)
		time.sleep(0.002)
		buf &= 0xFB               # Make EN = 0
		self.write_word(LCD_ADDR ,buf)
		
		# Send bit3-0 secondly
		buf = (comm & 0x0F) << 4
		buf |= 0x04               # RS = 0, RW = 0, EN = 1
		self.write_word(LCD_ADDR ,buf)
		time.sleep(0.002)
		buf &= 0xFB               # Make EN = 0
		self.write_word(LCD_ADDR ,buf)

	def send_data(self, data):
		# Send bit7-4 firstly
		buf = data & 0xF0
		buf |= 0x05               # RS = 1, RW = 0, EN = 1
		self.write_word(LCD_ADDR ,buf)
		time.sleep(0.002)
		buf &= 0xFB               # Make EN = 0
		self.write_word(LCD_ADDR ,buf)
		
		# Send bit3-0 secondly
		buf = (data & 0x0F) << 4
		buf |= 0x05               # RS = 1, RW = 0, EN = 1
		self.write_word(LCD_ADDR ,buf)
		time.sleep(0.002)
		buf &= 0xFB               # Make EN = 0
		self.write_word(LCD_ADDR ,buf)

	##初始化
	def init_lcd(self):
		try:
			self.send_command(0x33) # Must initialize to 8-line mode at first
			time.sleep(0.005)
			self.send_command(0x32) # Then initialize to 4-line mode
			time.sleep(0.005)
			self.send_command(0x28) # 2 Lines & 5*7 dots
			time.sleep(0.005)
			self.send_command(0x0C) # Enable display without cursor
			time.sleep(0.005)
			self.send_command(0x01) # Clear Screen
			logging.info('LCD init over')
			BUS.write_byte(LCD_ADDR ,0x08)
			logging.info('LCD turning on BLight')
		except:
			return False
		else:
			return True

	def clear_lcd(self):
		self.send_command(0x01) # Clear Screen

	def print_lcd(self, x, y, str):
		if x < 0:
			x = 0
		if x > 15:
			x = 15
		if y <0:
			y = 0
		if y > 1:
			y = 1

		# Move cursor
		addr = 0x80 + 0x40 * y + x
		self.send_command(addr)
		
		for chr in str:
			self.send_data(ord(chr))  ##返回ASCII码十进制数

